.. Copyright 2013-2021 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Stubble -- A collection of tools for writing stubs in unit tests (reahl.stubble)
================================================================================


Stubble's docs have moved:
- :doc:`Introduction <../stubble/introduction>`
- :doc:`API reference <../stubble/index>`
